# -*- coding: utf-8 -*-
##############################################################################
#
#    Copyright (C) 2010-2013 Associazione OpenERP Italia
#    (<http://www.openerp-italia.org>).
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from osv import osv
from tools.translate import _
import datetime


class account_invoice(osv.osv):
    _inherit = 'account.invoice'

    def action_number(self, cr, uid, ids, context=None):
        super(account_invoice, self).action_number(cr, uid, ids, context)
        for obj_inv in self.browse(cr, uid, ids):
            inv_type = obj_inv.type
            if inv_type == 'in_invoice' or inv_type == 'in_refund':
                return True
            number = obj_inv.number
            date_invoice = obj_inv.date_invoice
            journal = obj_inv.journal_id.id
            res = self.search(cr, uid, [('type', '=', inv_type), ('date_invoice', '>', date_invoice),
                                        ('number', '<', number), ('journal_id', '=', journal)])
            if res:
                raise osv.except_osv(_('Date Inconsistency'),
                                     _('Cannot create invoice! Post the invoice with a greater date'))
        return True
    
    def onchange_partner_id(self, cr, uid, ids, i_type, partner_id, date_invoice, payment_term, partner_bank_id, company_id, context=None):
        result = super(account_invoice, self).onchange_partner_id(cr, uid, ids, i_type, partner_id, date_invoice, payment_term, partner_bank_id, company_id)
        
        fp_result = self.onchange_check_fiscal_position(cr, uid, ids, date_invoice, partner_id)
        if fp_result['value']:
            result['value']['fiscal_position'] = fp_result['value']['fiscal_position']
        return result
    
    def onchange_check_fiscal_position(self, cr, uid, ids, date_invoice, partner_id, context=None):
        if partner_id:
            if not date_invoice:
                date_invoice = datetime.datetime.now().strftime('%Y-%m-%d')
            fiscal_position_ids = self.pool.get('account.fiscal.position').search(cr, uid, [
                ('partner_id', '=', partner_id), ('end_validity', '>=', date_invoice), '|', ('date', '<=', date_invoice), ('date', '=', False)
            ])
            if fiscal_position_ids:
                return {'value': {'fiscal_position': fiscal_position_ids[0]}}
            else:
                partner = self.pool.get('res.partner').browse(cr, uid, partner_id)
                if partner.property_account_position:
                    return {'value': {'fiscal_position': partner.property_account_position.id}}
                else:
                    return {'value': {'fiscal_position': False}}
        return {'value': {}}
