# -*- coding: utf-8 -*-
##############################################################################
#    
#    Copyright (C) 2013 Didotech Inc. (<http://www.didotech.com>)
#    All Rights Reserved
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as published
#    by the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

import time
from report import report_sxw


class Parser(report_sxw.rml_parse):

    def __init__(self, cr, uid, name, context):
        super(Parser, self).__init__(cr, uid, name, context)
        
        self.localcontext.update({
            'time': time,
            'invoice_tree': self._get_invoice_tree,
            'italian_number': self._get_italian_number,
        })
    
    def _get_italian_number(self, number, precision=2, no_zero=False):
        if not number and no_zero:
            return ''
        elif not number:
            return '0,00'
        
        if number < 0:
            sign = '-'
        else:
            sign = ''
        ## Requires Python >= 2.7:
        #before, after = "{:.{digits}f}".format(number, digits=precision).split('.')
        ## Works with Python 2.6:
        before, after = "{0:10.{digits}f}".format(number, digits=precision).strip('- ').split('.')
        
        belist = []
        end = len(before)
        for i in range(3, len(before) + 3, 3):
            start = len(before) - i
            if start < 0:
                start = 0
            belist.append(before[start: end])
            end = len(before) - i
        before = '.'.join(reversed(belist))
        
        if no_zero and int(number) == float(number):
            return sign + before
        else:
            return sign + before + ',' + after
    
    def get_description(self, ddt_name, order_name):
        ddt_obj = self.pool.get('stock.picking')
        order_obj = self.pool.get('sale.order')
        description = []
        
        if ddt_name:
            ddt_ids = ddt_obj.search(self.cr, self.uid, [('name', '=', ddt_name)])
            if len(ddt_ids) == 1:
                ddt = ddt_obj.browse(self.cr, self.uid, ddt_ids[0])
                ## Ex: Rif. Ns. DDT 2012/0335
                description.append(u'Rif. Ns. {ddt}'.format(ddt=ddt.ddt_number))
        
        if order_name:
            order_ids = order_obj.search(self.cr, self.uid, [('name', '=', order_name)])
            if len(order_ids) == 1:
                order = order_obj.browse(self.cr, self.uid, order_ids[0])
                description.append(u'Rif. Ns. Ordine {order}'.format(order=order.name))
            
        return ' / '.join(description)
        
    def _get_invoice_tree(self, invoice_lines):
        invoice = {}
        invoice_list = []
        
        for line in invoice_lines:
            if line.origin and ':' in line.origin:
                ddt, sale_order = line.origin.split(':')
            elif line.origin:
                ddt = False
                sale_order = line.origin
            else:
                ddt = False
                sale_order = False
            
            if ddt in invoice:
                invoice[ddt]['lines'].append(line)
            else:
                description = self.get_description(ddt, sale_order)
                invoice[ddt] = {'description': description, 'lines': [line]}
        
        for key in invoice.keys():
            invoice_list.append(invoice[key])
        return invoice_list
        
